@@ -145,6 +145,7 @@ KEY__email_account_protocol = "protocol"
 KEY__email_account_host = "host"
 KEY__email_account_port = "port"
 KEY__email_account_username = "username"
+KEY__email_account_password = "password"
 KEY__email_account_send_name = "send_name"
 KEY__encrypted_address = "encrypted_address"
 KEY__password_id = "password_id"
@@ -208,7 +209,7 @@ VAULT_KEY__allow_jaaql_uninstall = "Allow jaaql uninstall"
 ENVIRON__vault_key = "JAAQL_VAULT_PASSWORD"
 ENVIRON__local_install = "JAAQL_LOCAL_INSTALL"
 ENVIRON__jaaql_profiling = "JAAQL_PROFILING"
-ENVIRON__email_credentials = "JAAQL_EMAIL_CREDENTIALS"
+ENVIRON__email_accounts = "JAAQL_EMAIL_ACCOUNTS"
 ENVIRON__install_path = "INSTALL_PATH"
 ENVIRON__sentinel_url = "SENTINEL_URL"
 ENVIRON__canned_queries = "CANNED_QUERIES"
@@ -272,5 +273,5 @@ ROLE__postgres = "postgres"
 
 PROTOCOL__postgres = "postgresql://"
 
-VERSION = "4.3.5"
+VERSION = "4.3.6"
 
