@@ -1,5 +1,8 @@
-CREATE ROLE jaaql__registered;
-CREATE DOMAIN safe_path AS varchar(255) CHECK (VALUE ~* '^[a-z0-9_\-\/]+$');
+CREATE ROLE registered;
+CREATE ROLE anonymous;
+GRANT anonymous TO registered;
+
+CREATE DOMAIN safe_path AS varchar(255) CHECK (VALUE ~* '^[a-z0-9_\-\/]+(\.[a-zA-Z0-9]+)?$');
 
 -- Install script
 -- (1) Create tables
@@ -36,7 +39,7 @@ create table email_account (
     name varchar(60) not null,
     PRIMARY KEY (name),
     send_name varchar(255) not null,
-    protocol varchar(4) not null,
+    protocol varchar(4) not null default 'smtp',
     check (protocol in ('smtp')),
     host varchar(255) not null,
     port integer not null,
@@ -150,82 +153,6 @@ create view my_email_template_defaults as (
 );
 GRANT SELECT ON my_email_template_defaults TO PUBLIC;
 
-create function add_email_account(name varchar(60), send_name varchar(255), host varchar(255), port integer, username varchar(255), encrypted_password text) returns void as
-$$
-BEGIN
-    INSERT INTO email_account (name, send_name, protocol, host, port, username, encrypted_password)
-    VALUES (add_email_account.name, add_email_account.send_name, 'smtp',
-            add_email_account.host, add_email_account.port, add_email_account.username,
-            add_email_account.encrypted_password);
-END
-$$ language plpgsql SECURITY DEFINER;
-
-create function drop_email_account(name varchar(60)) returns void as
-$$
-BEGIN
-    DELETE FROM email_account WHERE email_account.name = drop_email_account.name;
-END
-$$ language plpgsql SECURITY DEFINER;
-
-create function register_email_template(name varchar(60), application character varying(63), subject varchar(255),
-                                        description text, app_relative_path safe_path = null, schema character varying(63) = null,
-                                        data_validation_table postgres_addressable_name = null, data_validation_view postgres_addressable_name = null, recipient_validation_view postgres_addressable_name = null,
-                                        allow_signup boolean = false, allow_confirm_signup_attempt boolean = false, allow_reset_password boolean = false,
-                                        default_email_signup boolean = null, _default_email_already_signed_up boolean = null, default_reset_password boolean = null) returns void as
-$$
-BEGIN
-    if register_email_template.default_email_signup is false then
-        register_email_template.default_email_signup = null;
-    end if;
-    if _default_email_already_signed_up is false then
-        _default_email_already_signed_up = null;
-    end if;
-    if register_email_template.default_reset_password is false then
-        register_email_template.default_reset_password = null;
-    end if;
-    INSERT INTO email_template(name, application,
-                               subject, description, app_relative_path,
-                               schema, data_validation_table, data_validation_view,
-                               recipient_validation_view, allow_signup, allow_confirm_signup_attempt,
-                               allow_reset_password, default_email_signup, default_email_already_signed_up,
-                               default_reset_password) VALUES (
-                                                                                           register_email_template.name, register_email_template.application,
-                                                                                           register_email_template.subject, register_email_template.description, register_email_template.app_relative_path,
-                                                                                           register_email_template.schema, register_email_template.data_validation_table, register_email_template.data_validation_view,
-                                                                                           register_email_template.recipient_validation_view, register_email_template.allow_signup, register_email_template.allow_confirm_signup_attempt,
-                                                                                           register_email_template.allow_reset_password, register_email_template.default_email_signup, _default_email_already_signed_up,
-                                                                                           register_email_template.default_reset_password);
-END
-$$ language plpgsql SECURITY DEFINER;
-
-create function deregister_email_template(_name varchar(60)) returns void as
-$$
-BEGIN
-    DELETE FROM email_template WHERE name = _name;
-END
-$$ language plpgsql SECURITY DEFINER;
-
-create function associate_email_template_with_application_configuration(template varchar(60), application character varying(63), configuration varchar(63),
-                                                                        account varchar(60), override_send_name varchar(255) = null) returns void as
-$$
-BEGIN
-    INSERT INTO email_template_configuration(application, configuration,
-                                             template, account, override_send_name)
-                                             VALUES (associate_email_template_with_application_configuration.application, associate_email_template_with_application_configuration.configuration,
-                                                     associate_email_template_with_application_configuration.template, associate_email_template_with_application_configuration.account,
-                                                     associate_email_template_with_application_configuration.override_send_name);
-END
-$$ language plpgsql SECURITY DEFINER;
-
-create function disassociate_email_template_with_application_configuration(template varchar(60), application character varying(63), configuration varchar(63)) returns void as
-$$
-BEGIN
-    DELETE FROM email_template_configuration etc WHERE etc.application = disassociate_email_template_with_application_configuration.application
-                                                 AND etc.template = disassociate_email_template_with_application_configuration.template
-                                                 AND etc.configuration = disassociate_email_template_with_application_configuration.configuration;
-END
-$$ language plpgsql SECURITY DEFINER;
-
 -- account_password...
 alter table account_password add constraint account_password__account
     foreign key (account)
@@ -270,8 +197,10 @@ DECLARE
 BEGIN
     INSERT INTO account (username) VALUES (enc_username) RETURNING user_id INTO account_id;
     EXECUTE 'CREATE ROLE ' || quote_ident(account_id);
-    if is_public is null then
-        EXECUTE 'GRANT jaaql__registered TO ' || quote_ident(account_id);
+    if is_public then
+        EXECUTE 'GRANT anonymous TO ' || quote_ident(account_id);
+    else
+        EXECUTE 'GRANT registered TO ' || quote_ident(account_id);
     end if;
     return account_id;
 END
@@ -283,7 +212,7 @@ BEGIN
     UPDATE account SET deleted = current_timestamp WHERE user_id = session_user;
 END
 $$ language plpgsql SECURITY DEFINER;
-GRANT execute on function close_my_account() to jaaql__registered;
+GRANT execute on function close_my_account() to registered;
 
 create table renderable_document (
     name      varchar(40) NOT null,
@@ -359,7 +288,7 @@ create view my_logs as (
     INNER JOIN account_ip ip ON log.login_ip = ip.id
     ORDER BY occurred DESC
 );
-grant select on my_logs to jaaql__registered;
+grant select on my_logs to registered;
 
 create view my_ips as (
     SELECT
@@ -371,7 +300,7 @@ create view my_ips as (
     INNER JOIN account us ON us.user_id = ip.account AND us.deleted is null AND us.user_id = session_user
     ORDER BY first_login DESC
 );
-grant select on my_ips to jaaql__registered;
+grant select on my_ips to registered;
 
 create view fetch_recent_passwords as (
     SELECT
